@@ -1,4 +1,4 @@
-{-# LANGUAGE DeriveDataTypeable, FlexibleInstances, OverloadedStrings, StandaloneDeriving #-}
+{-# LANGUAGE CPP, DeriveDataTypeable, FlexibleInstances, OverloadedStrings, StandaloneDeriving #-}
 {-# OPTIONS_GHC -Wall -fno-warn-orphans #-}
 module Debian.Orphans where
 
@@ -6,7 +6,6 @@ import Data.Function (on)
 import Data.Generics (Data, Typeable)
 import Data.List (intersperse, isPrefixOf)
 import Data.Maybe (fromMaybe)
-import Data.Monoid ((<>))
 import Debian.Changes (ChangeLog(..), ChangeLogEntry(..))
 import Debian.Pretty (PP(PP, unPP))
 import Debian.Relation (ArchitectureReq(..), Relation(..), VersionReq(..))
@@ -96,17 +95,23 @@ instance Pretty (PP VersionRange) where
     pretty (PP range) = (cataVersionRange prettyRange . normaliseVersionRange) range
 
 prettyRange :: VersionRangeF Text.PrettyPrint.HughesPJ.Doc -> Text.PrettyPrint.HughesPJ.Doc
+#if !MIN_VERSION_Cabal(3,4,0)
 prettyRange AnyVersionF                     = (text "*")
+#endif
 prettyRange (ThisVersionF v)                = text "=" <> pretty (PP v)
 prettyRange (LaterVersionF v)               = text ">" <> pretty (PP v)
 prettyRange (EarlierVersionF v)             = text "<" <> pretty (PP v)
 prettyRange (OrLaterVersionF v)             = text ">=" <> pretty (PP v)
 prettyRange (OrEarlierVersionF v)           = text "<=" <> pretty (PP v)
+#if !MIN_VERSION_Cabal(3,4,0)
 prettyRange (WildcardVersionF v)            = text "=" <> pretty (PP v) <> text ".*" -- not exactly right
+#endif
 prettyRange (MajorBoundVersionF v)          = text " >= " <> pretty (PP v) -- maybe this will do?
 prettyRange (UnionVersionRangesF v1 v2)     = text "(" <> v1 <> text " || " <> v2 <> text ")"
 prettyRange (IntersectVersionRangesF v1 v2) = text "(" <> v1 <> text " && " <> v2 <> text ")"
+#if !MIN_VERSION_Cabal(3,4,0)
 prettyRange (VersionRangeParensF v)         = text "(" <> v <> text ")"
+#endif
 
 instance Pretty (PP Version) where
     pretty = text . prettyShow . unPP
